Violation

Struct Violation 

#[non_exhaustive]
pub struct Violation { pub field: Option<&'static str>, pub message: &'static str, }
A single failed constraint, optionally associated with a named field.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
field: Option<&'static str>

The field name, if validation was run on a named field.

message: &'static str

A human-readable description of the constraint that failed.

Implementations

Source

impl Violation

pub const fn new(message: &'static str) -> Self

Creates a violation without a field name.

pub const fn with_field(field: &'static str, message: &'static str) -> Self

Creates a violation associated with a named field.