Violation

Struct Violation 

pub struct Violation {
    pub field: Option<&'static str>,
    pub message: &'static str,
}
A single failed constraint, optionally associated with a named field.

Fields

field: Option<&'static str>

The field name, if validation was run on a named field.

message: &'static str

A human-readable description of the constraint that failed.

Implementations

Source

impl Violation

pub const fn new(message: &'static str) -> Self

Creates a violation without a field name.

pub const fn with_field(field: &'static str, message: &'static str) -> Self

Creates a violation associated with a named field.